@@ -460,4 +460,14 @@ mod tests {
 
     }
 
+    mod uuid {
+        use crate::Uuid;
+
+        #[test]
+        fn should_convert_a_str_to_uuid() {
+
+            assert_eq!(Uuid{ timestamp: 1636523479865480266, sequence: 1 }, Uuid::from_string("1636523479865480266-1"))
+        }
+    }
+
 }
\ No newline at end of file
